# This specfile is licensed under:
#
# Copyright (C) 2022 Maxwell G <gotmax@e.email>
# SPDX-License-Identifier: MIT
# License text: https://spdx.org/licenses/MIT.html

%bcond libdnf5 %[0%{?fedora} >= 38]

Name:           fedrq
Version:        1.5.0^30.20250420.71dc477
Release:        1%{?dist}
Summary:        A tool to query the Fedora and EPEL repositories

# - code is GPL-2.0-or-later
# - the data and config files in fedrq/data are UNLICENSEed
# - Embeded repo defs are MIT.
# - PSF-2.0 code copied from Cpython 3.11 for older Python versions
License:        GPL-2.0-or-later AND Unlicense AND MIT AND PSF-2.0
URL:            https://fedrq.gtmx.me
%global furl    https://git.sr.ht/~gotmax23/fedrq
Source0:        fedrq-1.5.0^30.20250420.71dc477.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel
# Test deps
BuildRequires:  createrepo_c
BuildRequires:  distribution-gpg-keys
BuildRequires:  python3-argcomplete
BuildRequires:  python3-dnf
%if %{with libdnf5}
BuildRequires:  python3-libdnf5
%endif
# Manpage
BuildRequires:  scdoc

Requires:       (python3-dnf or python3-libdnf5)
Suggests:       (python3-libdnf5 if dnf5)
Requires:       distribution-gpg-keys
Recommends:     fedora-repos-rawhide
Recommends:     python3-argcomplete

# fedrq config --dump
Recommends:     python3-tomli-w


%description
fedrq is a tool to query the Fedora and EPEL repositories.


%prep
%autosetup -p1


%generate_buildrequires
%pyproject_buildrequires -x test


%build
%py3_shebang_fix contrib/api_examples/*.py

%pyproject_wheel
scdoc <doc/fedrq.1.scd >fedrq.1
scdoc <doc/fedrq.5.scd >fedrq.5
register-python-argcomplete --shell bash fedrq >fedrq.bash
register-python-argcomplete --shell fish fedrq >fedrq.fish


%install
%pyproject_install
%pyproject_save_files fedrq
install -Dpm 0644 fedrq.1 -t %{buildroot}%{_mandir}/man1/
install -Dpm 0644 fedrq.5 -t %{buildroot}%{_mandir}/man5/
install -Dpm 0644 fedrq.bash %{buildroot}%{bash_completions_dir}/fedrq
install -Dpm 0644 fedrq.fish %{buildroot}%{fish_completions_dir}/fedrq.fish


%check
bash -x ./tests/test_data/build.sh

# Use python3 -m to ensure the current directory is part of sys.path so the
# tests can import from its own package.

FEDRQ_BACKEND=dnf %{py3_test_envvars} \
    %{python3} -m pytest -v -m "not no_rpm_mock"

%if %{with libdnf5}
# Some tests are failing only in mock and only with Python 3.12
#   RuntimeError: Failed to download metadata
%if v"0%{?python3_version}" >= v"3.12"
%global skips %{shrink:
    not test_smartcache_not_used
    and not test_smartcache_config
    and not test_baseurl_repog
}
%endif
FEDRQ_BACKEND=libdnf5 %{py3_test_envvars} \
    %{python3} -m pytest -v -m "not no_rpm_mock" %{?skips:-k '%{skips}'}
%endif


%files -f %{pyproject_files}
# Licenses are included in the wheel
%license %{_licensedir}/fedrq/
%doc README.md CONTRIBUTING.md NEWS.md contrib/api_examples
%{_bindir}/fedrq*
%{bash_completions_dir}/fedrq
%{fish_completions_dir}/fedrq.fish
%{_mandir}/man1/fedrq.1*
%{_mandir}/man5/fedrq.5*


%changelog
* Sun Apr 20 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^30.20250420.71dc477-1
- requirements: update locked deps

* Sun Apr 20 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^29.20250420.7b80014-1
- backends PackageQueryCompat: add __contains__ to interface

* Thu Apr 10 2025 builds.sr.ht automation <auto@gtmx.me> - 1.5.0^28.20250410.27c5095-1
- ci: refresh locked dependencies

* Fri Apr 04 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^27.20250404.62ee0eb-1
- ci: update pinned dependencies

* Fri Apr 04 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^26.20250404.99409d1-1
- subpkgs: mark --include-src as experimental

* Fri Apr 04 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^25.20250404.298e2e6-1
- tests: add additional formatters tests and fixup queryformat

* Fri Apr 04 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^24.20250404.bcb97b6-1
- lint: update basedpyright

* Thu Apr 03 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^23.20250403.882db39-1
- internal whatrequires: small perf improvement to _extra_exact

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^22.20250331.0b76adc-1
- subpkgs: add --include-src

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^21.20250331.0dcac72-1
- Add queryformat formatter

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^20.20250331.a36fee9-1
- fixup! config: warn about invalid config options

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^19.20250331.a3b1c6e-1
- nox: silence pydantic deprecation warnings

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^18.20250331.fc6b9bc-1
- dev: add contrib/devenv.sh

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^17.20250331.cee33ee-1
- requirements: fix mkdocstrings deprecation warnings

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^16.20250331.0e56573-1
- lint: remove invalid copyright header from REUSE.toml

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^15.20250331.aab133e-1
- config: warn about invalid config options

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^14.20250331.e0ec673-1
- ci: update locked dependencies

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^13.20250331.c24f6e0-1
- lint basedpyright: write baseline

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^12.20250331.b47ecd6-1
- internal: typing and pydantic model fixes

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^11.20250331.f46ffa0-1
- doc: improve API documentation

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^10.20250331.bc039b6-1
- release_repo: remove manual dict view methods

* Mon Mar 31 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^9.20250331.faef8d9-1
- internal formatters: make Formatters properly immutable

* Sun Mar 16 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^8.20250316.5a383c4-1
- lint basedpyright: disable useTypingExtensions

* Sun Mar 16 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^7.20250316.a986dc0-1
- lint: configure target-version in ruff

* Sun Mar 16 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^6.20250316.cecfc1d-1
- dev: add hard dependency on tomli for typing

* Sun Mar 16 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^5.20250316.24adae9-1
- lint basedpyright: set pythonVersion to minimum supported

* Sun Mar 16 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^4.20250316.4f3940d-1
- Fix handling of --repo with @local release

* Sun Mar 16 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^3.20250316.3d1e49f-1
- contrib Containerfile: remove reference to modular

* Thu Mar 13 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^2.20250313.3f46f5e-1
- contrib container: use dnf5

* Sat Mar 01 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0^1.20250301.8400791-1
- Post-release version bump

* Sat Mar 01 2025 Maxwell G <maxwell@gtmx.me> - 1.5.0-1
- Release 1.5.0.

* Fri Nov 01 2024 Maxwell G <maxwell@gtmx.me> - 1.4.0-1
- Release 1.4.0.

* Tue Aug 27 2024 Maxwell G <maxwell@gtmx.me> - 1.3.0-1
- Release 1.3.0.

* Sat Aug 03 2024 Maxwell G <maxwell@gtmx.me> - 1.2.0-1
- Release 1.2.0.

* Wed May 01 2024 Maxwell G <maxwell@gtmx.me> - 1.1.0-1
- Release 1.1.0.

* Mon Apr 01 2024 Maxwell G <maxwell@gtmx.me> - 1.0.0-1
- Release 1.0.0.

* Tue Feb 13 2024 Maxwell G <maxwell@gtmx.me> - 0.15.0-1
- Release 0.15.0.

* Wed Feb 07 2024 Maxwell G <maxwell@gtmx.me> - 0.14.0-1
- Release 0.14.0.

* Mon Dec 18 2023 Maxwell G <maxwell@gtmx.me> - 0.13.0-1
- Release 0.13.0.

* Mon Sep 11 2023 Maxwell G <maxwell@gtmx.me> - 0.12.0-1
- Release 0.12.0.

* Thu Aug 31 2023 Maxwell G <maxwell@gtmx.me> - 0.11.0-1
- Release 0.11.0.

* Wed Jul 12 2023 Maxwell G <maxwell@gtmx.me> - 0.10.0-1
- Release 0.10.0.

* Thu Jun 29 2023 Maxwell G <maxwell@gtmx.me> - 0.9.0-1
- Release 0.9.0.

* Wed Jun 21 2023 Maxwell G <maxwell@gtmx.me> - 0.8.0-1
- Release 0.8.0.

* Wed May 31 2023 Maxwell G <maxwell@gtmx.me> - 0.7.1-1
- Release 0.7.1.

* Tue May 30 2023 Maxwell G <maxwell@gtmx.me> - 0.7.0-1
- Release 0.7.0.

* Sat Apr 08 2023 Maxwell G <maxwell@gtmx.me> - 0.6.0-1
- Release 0.6.0

* Sat Mar 18 2023 Maxwell G <maxwell@gtmx.me> - 0.5.0-1
- Release 0.5.0

* Tue Mar 14 2023 Maxwell G <maxwell@gtmx.me> - 0.4.1-1
- Release 0.4.1

* Tue Feb 21 2023 Maxwell G <maxwell@gtmx.me> - 0.4.0-1
- Release 0.4.0

* Mon Feb 13 2023 Maxwell G <gotmax@e.email> - 0.3.0-1
- Release 0.3.0

* Sat Jan 14 2023 Maxwell G <gotmax@e.email> - 0.2.0-1
- Release 0.2.0

* Tue Jan 03 2023 Maxwell G <gotmax@e.email> 0.1.0-1
- Release 0.1.0

* Tue Dec 20 2022 Maxwell G <gotmax@e.email> 0.0.2-1
- Release 0.0.2

* Tue Dec 20 2022 Maxwell G <gotmax@e.email> 0.0.1-1
- Release 0.0.1
